@@ -4,13 +4,13 @@ Attean - A Semantic Web Framework
 
 =head1 VERSION
 
-This document describes Attean version 0.019
+This document describes Attean version 0.030	
 
 =head1 SYNOPSIS
 
-  use v5.14;
   use Attean;
   use Attean::RDF qw(iri);
+  
   my $store = Attean->get_store('Memory')->new();
   my $parser = Attean->get_parser('NTriples')->new();
   
@@ -18,7 +18,8 @@ This document describes Attean version 0.019
   my $iter = $parser->parse_iter_from_io(\*STDIN);
   
   # add a graph name to all triples
-  my $quads = $iter->as_quads(iri('http://graph-name/'));
+  my $graph = iri('http://graph-name/');
+  my $quads = $iter->as_quads($graph);
   
   $store->add_iter($quads);
   my $model = Attean::QuadModel->new( store => $store );
@@ -27,6 +28,15 @@ This document describes Attean version 0.019
     say $quad->object->ntriples_string;
   }
 
+  # run a SPARQL query and iterate over the results
+  my $sparql = 'SELECT * WHERE { ?s ?p ?o }';
+  my $s = Attean->get_parser('SPARQL')->new();
+  my ($algebra)	= $s->parse($sparql);
+  my $results = $model->evaluate($algebra, $graph);
+  while (my $r = $results->next) {
+    say $r->as_string;
+  }
+
 =head1 DESCRIPTION
 
 Attean provides APIs for parsing, storing, querying, and serializing
@@ -41,7 +51,7 @@ Semantic Web (RDF and SPARQL) data.
 package Attean {
 	use v5.14;
 	use warnings;
-	our $VERSION	= '0.019';
+	our $VERSION	= '0.030';
 	use Attean::API;
 	
 	use Attean::Blank;
@@ -68,6 +78,7 @@ package Attean {
 	use HTTP::Negotiate qw(choose);
 	use List::MoreUtils qw(any all);
 	use Module::Load::Conditional qw(can_load);
+	use Role::Tiny ();
 	use Sub::Util qw(set_subname);
 	use namespace::clean;
 	
@@ -109,9 +120,24 @@ returns undef.
 		my $self	= shift;
 		return $self->_get_plugin('stores', shift);
 	}
-	
+
+=item C<< temporary_model >> 
+
+Returns a temporary, mutable quad model based on a L<AtteanX::Store::Memory> store.
+
+=cut
+
+	sub temporary_model {
+	  my $self = shift;
+	  return Attean::MutableQuadModel->new( store => $self->get_store('Memory')->new() )
+	}
+
+
+
 =item C<< get_serializer( $NAME ) >>
 
+=item C<< get_serializer( filename => $FILENAME ) >>
+
 =item C<< get_serializer( media_type => $MEDIA_TYPE ) >>
 
 Attempts to find a L<Attean::API::Serializer> serializer class with the given
@@ -126,11 +152,24 @@ returns undef.
 	sub get_serializer {
 		my $self	= shift;
 		my $role	= 'Attean::API::Serializer';
-		return $self->_get_plugin('serializers', shift, $role) if (scalar(@_) == 1);
+
+		if (scalar(@_) == 1) {
+			my $name	= shift;
+			my $p		= $self->_get_plugin('serializers', $name, $role);
+			return $p if $p;
+			
+			foreach my $type (qw'filename media_type') {
+				my $p	= $self->get_serializer($type => $name);
+				return $p if $p;
+			}
+			return;
+		}
 		my $type	= shift;
-		my %method	= (media_type => 'media_types');
+		my %method	= (filename => 'file_extensions', media_type => 'media_types');
 		if (my $method = $method{ $type }) {
 			my $value	= shift;
+			$value	=~ s/^.*[.]// if ($type eq 'filename');
+			$value	=~ s/;.*$// if ($type eq 'media_type');
 			foreach my $p ($self->serializers()) {
 				if (can_load( modules => { $p => 0 })) {
 					next unless ($p->does($role));
@@ -163,7 +202,19 @@ returns undef.
 	sub get_parser {
 		my $self	= shift;
 		my $role	= 'Attean::API::Parser';
-		return $self->_get_plugin('parsers', shift, $role) if (scalar(@_) == 1);
+		
+		if (scalar(@_) == 1) {
+			my $name	= shift;
+			my $p		= $self->_get_plugin('parsers', $name, $role);
+			return $p if $p;
+			
+			foreach my $type (qw'filename media_type') {
+				my $p	= $self->get_parser($type => $name);
+				return $p if $p;
+			}
+			return;
+		}
+		
 		my $type	= shift;
 		my %method	= (filename => 'file_extensions', media_type => 'media_types');
 		if (my $method = $method{ $type }) {
@@ -400,7 +451,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams.
+Copyright (c) 2014--2020 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
