@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.021
+This document describes Attean::API::Iterator version 0.030
 
 =head1 DESCRIPTION
 
@@ -94,10 +94,9 @@ elements from the referent.
 
 =cut
 
-package Attean::API::Iterator 0.021 {
+package Attean::API::Iterator 0.030 {
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
-	use Role::Tiny;
 	use Carp qw(confess);
 
 	use Moo::Role;
@@ -112,30 +111,30 @@ package Attean::API::Iterator 0.021 {
 		my $args	= shift;
 		$self->$orig($args);
 		my $role	= $self->item_type;
-		if (Role::Tiny->is_role($role)) {
+		if (Moo::Role->is_role($role)) {
 			my $check	= sub {
 				my $check = shift;
-				return ($role eq $check or Role::Tiny::does_role($role, $check));
+				return ($role eq $check or Moo::Role::does_role($role, $check));
 			};
 			if ($check->('Attean::API::Quad')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::QuadIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::QuadIterator');
 			} elsif ($check->('Attean::API::Triple')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TripleIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::TripleIterator');
 			} elsif ($check->('Attean::API::TripleOrQuad')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
 			} elsif ($check->('Attean::API::Result')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::ResultIterator');
 				my $vars	= $args->{variables} // confess "Construction of a Attean::API::ResultIterator must include a variables list";
 				$self->variables($vars);
 			} elsif ($check->('Attean::API::Term')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TermIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::TermIterator');
 			} elsif ($check->('Attean::API::ResultOrTerm')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
 				$self->variables($args->{variables} || []);
 			}
 
 			if ($self->does('Attean::API::RepeatableIterator') and $check->('Attean::API::Binding')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::CanonicalizingBindingSet');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::CanonicalizingBindingSet');
 			}
 		}
 	};
@@ -277,7 +276,20 @@ Print each item as it is consumed (with the string generated by C<< as_string >>
 	}
 }
 
-package Attean::API::RepeatableIterator 0.021 {
+package Attean::API::StringyItemIterator 0.030 {
+	use Moo::Role;
+	sub uniq {
+		my $self	= shift;
+		
+		my %seen;
+		return $self->grep(sub {
+			my $r	= shift;
+			return not($seen{ $r->as_string }++);
+		});
+	}
+}
+
+package Attean::API::RepeatableIterator 0.030 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -301,6 +313,13 @@ package Attean::API::RepeatableIterator 0.021 {
 		return $self;
 	}
 
+	sub size {
+		my $self	= shift;
+		my @elements	= $self->elements;
+		warn 'RepeatableIterator->size';
+		return scalar(@elements);
+	}
+	
 	with 'Attean::API::Iterator';
 }
 
@@ -313,10 +332,12 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.021 {
+package Attean::API::ResultOrTermIterator 0.030 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef Str);
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
+	with 'Attean::API::StringyItemIterator';
+	
 	sub canonicalize {
 		my $self	= shift;
 		my $mapper	= Attean::TermMap->canonicalization_map;
@@ -351,24 +372,72 @@ package Attean::API::ResultOrTermIterator 0.021 {
 	};
 }
 
-package Attean::API::TripleIterator 0.021 {
+package Attean::API::StatementIterator 0.030 {
+	use Moo::Role;
+	use Scalar::Util qw(blessed);
+	with 'Attean::API::StringyItemIterator';
+	requires 'variables';
+
+	sub matching_pattern {
+		my $self	= shift;
+		my @nodes	= @_;
+
+		my %bound;
+		my @pos_names	= $self->variables;
+		foreach my $pos (0 .. $#pos_names) {
+			my $n	= $nodes[ $pos ];
+			if (blessed($n) and $n->does('Attean::API::Variable')) {
+				$n	= undef;
+				$nodes[$pos]	= undef;
+			}
+			if (blessed($n)) {
+				$bound{ $pos_names[$pos] }	= $n;
+			}
+		}
+		
+		return $self->grep(sub {
+			my $q	= shift;
+			foreach my $key (keys %bound) {
+				my $term	= $q->$key();
+				unless ($term->equals( $bound{$key} )) {
+					return 0;
+				}
+			}
+			return 1;
+		});
+	}
+}
+
+package Attean::API::TripleIterator 0.030 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StatementIterator';
+
 	sub as_quads {
 		my $self	= shift;
 		my $graph	= shift;
 		return $self->map(sub { $_->as_quad($graph) }, 'Attean::API::Quad');
 	}
+
+	sub variables {
+		return qw(subject predicate object);
+	}
 }
 
-package Attean::API::QuadIterator 0.021 {
+package Attean::API::QuadIterator 0.030 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StatementIterator';
+	
+	sub variables {
+		return qw(subject predicate object graph);
+	}
 }
 
-package Attean::API::MixedStatementIterator 0.021 {
+package Attean::API::MixedStatementIterator 0.030 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StringyItemIterator';
 	sub as_quads {
 		my $self	= shift;
 		my $graph	= shift;
@@ -379,12 +448,12 @@ package Attean::API::MixedStatementIterator 0.021 {
 	}
 }
 
-package Attean::API::ResultIterator 0.021 {
+package Attean::API::ResultIterator 0.030 {
 	use Types::Standard qw(Str ArrayRef);
-
 	use Moo::Role;
 	
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StringyItemIterator';
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], required => 1);
 	sub join {
 		my $self	= shift;
@@ -404,7 +473,7 @@ package Attean::API::ResultIterator 0.021 {
 	}
 }
 
-package Attean::API::TermIterator 0.021 {
+package Attean::API::TermIterator 0.030 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
@@ -412,6 +481,7 @@ package Attean::API::TermIterator 0.021 {
 		return $self->map( $mapper );
 	}
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StringyItemIterator';
 }
 
 1;
@@ -420,6 +490,27 @@ __END__
 
 =back
 
+=head2 Methods on Roles Supporting Stringification
+
+For iterators over roles that provide an C<as_string> method, extra methods
+are provided. These iterators are:
+
+Attean::API::ResultOrTermIterator
+Attean::API::StatementIterator
+Attean::API::MixedStatementIterator
+Attean::API::ResultIterator
+Attean::API::TermIterator
+
+They provide the following methods:
+
+=over 4
+
+=item C<< uniq >>
+
+Returns a new iterator providing unique results (based on the stringified value of the underlying elements).
+
+=back
+
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
@@ -437,7 +528,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams.
+Copyright (c) 2014--2020 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
