@@ -7,7 +7,7 @@ Attean::Blank - RDF blank nodes
 
 =head1 VERSION
 
-This document describes Attean::Blank version 0.021
+This document describes Attean::Blank version 0.030
 
 =head1 SYNOPSIS
 
@@ -33,10 +33,10 @@ This role consumes L<Attean::API::Blank>, which provides the following methods:
 
 =cut
 
-package Attean::Blank 0.021 {
+package Attean::Blank 0.030 {
 	use Moo;
 	use Types::Standard qw(Str);
-	use Data::UUID;
+	use UUID::Tiny ':std';
 	use namespace::clean;
 	
 	has 'value' => (is => 'ro', isa => Str, required => 1);
@@ -49,8 +49,8 @@ package Attean::Blank 0.021 {
 		my $class	= shift;
 		
 		if (scalar(@_) == 0) {
-			my $uuid	= Data::UUID->new->create_hex;
-			return $class->$orig(value => $uuid);
+			my $uuid	= unpack('H*', create_uuid());
+			return $class->$orig(value => 'b' . $uuid);
 		} elsif (scalar(@_) == 1) {
 			my $value	= shift // '';
 			return $class->$orig(value => $value);
@@ -83,7 +83,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams.
+Copyright (c) 2014--2020 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
